pub struct DescriptorPublicKey(/* private fields */);Expand description
A descriptor public key.
Implementations
Sourceimpl DescriptorPublicKey
impl DescriptorPublicKey
Sourcepub fn from_string(public_key: String) -> Result<Self, DescriptorKeyError>
pub fn from_string(public_key: String) -> Result<Self, DescriptorKeyError>
Attempt to parse a string as a descriptor public key.
Sourcepub fn derive(
&self,
path: &DerivationPath,
) -> Result<Arc<Self>, DescriptorKeyError>
pub fn derive( &self, path: &DerivationPath, ) -> Result<Arc<Self>, DescriptorKeyError>
Derive the descriptor public key at the given derivation path.
Sourcepub fn extend(
&self,
path: &DerivationPath,
) -> Result<Arc<Self>, DescriptorKeyError>
pub fn extend( &self, path: &DerivationPath, ) -> Result<Arc<Self>, DescriptorKeyError>
Extend the descriptor public key by the given derivation path.
Sourcepub fn is_multipath(&self) -> bool
pub fn is_multipath(&self) -> bool
Whether or not this key has multiple derivation paths.
Sourcepub fn master_fingerprint(&self) -> String
pub fn master_fingerprint(&self) -> String
The fingerprint of the master key associated with this key, 0x00000000 if none.