bdkffi::keys

Struct DescriptorSecretKey

pub struct DescriptorSecretKey(/* private fields */);
A descriptor containing secret data.

Implementations

Source

impl DescriptorSecretKey

pub fn new( network: Network, mnemonic: &Mnemonic, password: Option<String>, ) -> Self

Construct a secret descriptor using a mnemonic.

pub fn from_string(private_key: String) -> Result<Self, DescriptorKeyError>

Attempt to parse a string as a descriptor secret key.

pub fn derive( &self, path: &DerivationPath, ) -> Result<Arc<Self>, DescriptorKeyError>

Derive a descriptor secret key at a given derivation path.

pub fn extend( &self, path: &DerivationPath, ) -> Result<Arc<Self>, DescriptorKeyError>

Extend the descriptor secret key by the derivation path.

pub fn as_public(&self) -> Arc<DescriptorPublicKey>

Return the descriptor public key corresponding to this secret.

pub fn secret_bytes(&self) -> Vec<u8>

Return the bytes of this descriptor secret key.