pub struct Mnemonic(/* private fields */);Expand description
A mnemonic seed phrase to recover a BIP-32 wallet.
Implementations
Sourceimpl Mnemonic
impl Mnemonic
Sourcepub fn from_string(mnemonic: String) -> Result<Self, Bip39Error>
pub fn from_string(mnemonic: String) -> Result<Self, Bip39Error>
Parse a string as a mnemonic seed phrase.
Sourcepub fn from_entropy(entropy: Vec<u8>) -> Result<Self, Bip39Error>
pub fn from_entropy(entropy: Vec<u8>) -> Result<Self, Bip39Error>
Construct a mnemonic given an array of bytes. Note that using weak entropy will result in a loss of funds. To ensure the entropy is generated properly, read about your operating system specific ways to generate secure random numbers.