pub struct DerivationPath(/* private fields */);Expand description
A BIP-32 derivation path.
Implementations
Sourceimpl DerivationPath
impl DerivationPath
Sourcepub fn new(path: String) -> Result<Self, Bip32Error>
pub fn new(path: String) -> Result<Self, Bip32Error>
Parse a string as a BIP-32 derivation path.
Sourcepub fn master() -> Arc<Self>
pub fn master() -> Arc<Self>
Returns derivation path for a master key (i.e. empty derivation path)
Sourcepub fn is_master(&self) -> bool
pub fn is_master(&self) -> bool
Returns whether derivation path represents master key (i.e. it’s length
is empty). True for m path.
Sourcepub fn child(&self, child_number: ChildNumber) -> Result<Arc<Self>, Bip32Error>
pub fn child(&self, child_number: ChildNumber) -> Result<Arc<Self>, Bip32Error>
Create a new DerivationPath that is a child of this one.
Sourcepub fn extend(&self, other: &DerivationPath) -> Arc<Self>
pub fn extend(&self, other: &DerivationPath) -> Arc<Self>
Concatenate self with path and return the resulting new path.
Sourcepub fn to_u32_vec(&self) -> Vec<u32>
pub fn to_u32_vec(&self) -> Vec<u32>
Returns the derivation path as a vector of u32 integers. Unhardened elements are copied as is. 0x80000000 is added to the hardened elements.