pub struct DescriptorSecretKey(/* private fields */);Expand description
A descriptor containing secret data.
Implementations
Sourceimpl DescriptorSecretKey
impl DescriptorSecretKey
Sourcepub fn new(
network: Network,
mnemonic: &Mnemonic,
password: Option<String>,
) -> Self
pub fn new( network: Network, mnemonic: &Mnemonic, password: Option<String>, ) -> Self
Construct a secret descriptor using a mnemonic.
Sourcepub fn from_string(private_key: String) -> Result<Self, DescriptorKeyError>
pub fn from_string(private_key: String) -> Result<Self, DescriptorKeyError>
Attempt to parse a string as a descriptor secret key.
Sourcepub fn derive(
&self,
path: &DerivationPath,
) -> Result<Arc<Self>, DescriptorKeyError>
pub fn derive( &self, path: &DerivationPath, ) -> Result<Arc<Self>, DescriptorKeyError>
Derive a descriptor secret key at a given derivation path.
Sourcepub fn extend(
&self,
path: &DerivationPath,
) -> Result<Arc<Self>, DescriptorKeyError>
pub fn extend( &self, path: &DerivationPath, ) -> Result<Arc<Self>, DescriptorKeyError>
Extend the descriptor secret key by the derivation path.
Sourcepub fn as_public(&self) -> Arc<DescriptorPublicKey>
pub fn as_public(&self) -> Arc<DescriptorPublicKey>
Return the descriptor public key corresponding to this secret.
Sourcepub fn secret_bytes(&self) -> Vec<u8> ⓘ
pub fn secret_bytes(&self) -> Vec<u8> ⓘ
Return the bytes of this descriptor secret key.